@@ -1,6 +1,6 @@
 /* Conversion of links to local files.
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
-   2014, 2015 Free Software Foundation, Inc.
+   Copyright (C) 2003-2011, 2014-2015, 2018-2019 Free Software
+   Foundation, Inc.
 
 This file is part of GNU Wget.
 
@@ -255,9 +255,9 @@ convert_links (const char *file, struct urlpos *links)
     write_backup_file (file, downloaded_file_return);
 
   /* Before opening the file for writing, unlink the file.  This is
-     important if the data in FM is mmaped.  In such case, nulling the
+     important if the data in FM is mapped.  In such case, nulling the
      file, which is what fopen() below does, would make us read all
-     zeroes from the mmaped region.  */
+     zeroes from the mapped region.  */
   if (unlink (file) < 0 && errno != ENOENT)
     {
       logprintf (LOG_NOTQUIET, _("Unable to delete %s: %s\n"),
@@ -303,7 +303,7 @@ convert_links (const char *file, struct urlpos *links)
         {
         case CO_CONVERT_TO_RELATIVE:
           /* Convert absolute URL to relative. */
-          {
+          if (link->local_name) {
             char *newname = construct_relative (file, link->local_name);
             char *quoted_newname = local_quote_string (newname,
                                                        link->link_css_p);
@@ -322,8 +322,8 @@ convert_links (const char *file, struct urlpos *links)
             xfree (newname);
             xfree (quoted_newname);
             ++to_file_count;
-            break;
           }
+          break;
         case CO_CONVERT_BASENAME_ONLY:
           {
             char *newname = convert_basename (p, link);
