@@ -1,6 +1,6 @@
 /* HTML parser for Wget.
-   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2015 Free Software Foundation, Inc.
+   Copyright (C) 1998-2011, 2015, 2018-2019 Free Software Foundation,
+   Inc.
 
 This file is part of GNU Wget.
 
